import { useState } from "react";
import { Button, Container, Row } from "react-bootstrap";
import { useTranslation } from "react-i18next";
import BoatTile from "../../components/BoatTile";
import StaffModal from "../../components/StaffModal";
import BoatInfo from "../../components/forms/BoatInfo";
import { useNavigate } from 'react-router-dom';


function BoatOverview() {
	const { t } = useTranslation();
	const [infoElement, setInfoElement] = useState<any>(undefined);
	const navigate = useNavigate();

	const boats = [{ id: 1, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: true }, { id: 2, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: true }, { id: 3, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: true },
	{ id: 4, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: true }, { id: 5, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: true }, { id: 6, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: true },
	{ id: 7, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: false }, { id: 8, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: false }, { id: 9, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: false },
	{ id: 10, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: false }, { id: 11, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: false }, { id: 12, boatName: "Canoe 1", time: "13:15-15:14", seats: 2, overdue: false },]

	return (
		<div className="text-center bg-light">
			{/*TODO: Make dynamic*/}

			<div className="boatViews text-center">
				<Row xs={1} xl={2}>
					<div>
						<div className="rentedOverdueView bg-white border my-2">
							<h2 className="my-3">{t("boatOverview.labelOverdue")}</h2>
							<div className="py-1">
								<Container>
									<div className="overdue-tiles text-center">
										<Row xs={1} md={2} >
											{boats.filter(x => x.overdue).map(x =>
												<BoatTile isInUse={true} key={x.id} boatName={x.boatName} time={x.time} persons={x.seats + " Person"} overdue={true} clickEvent={() => { setInfoElement(x) }}></BoatTile>
											)}
										</Row>
									</div>
									<Button variant="light" onClick={() => navigate('/staff/manage')} className="mt-3 shadow-sm bg-white border w-50 text-uppercase rounded-pill">{t("boatOverview.buttonShowAll")}</Button>
								</Container>
							</div>
						</div>
					</div>

					<div>
						<div className="rentedView bg-white border my-2">
							<h2 className="my-3">{t("boatOverview.labelCurrentlyRented")}</h2>
							<div className="py-1">
								<Container>
									<div className="rented-tiles text-center">
										<Row xs={1} md={2}>
											{boats.filter(x => !x.overdue).map(x =>
												<BoatTile isInUse={true} key={x.id} boatName={x.boatName} time={x.time} persons={x.seats + " Person"} overdue={false} clickEvent={() => { setInfoElement(x) }}></BoatTile>
											)}
										</Row>
									</div>
									<Button variant="light" onClick={() => navigate('/staff/manage')} className="mt-3 shadow-sm bg-white border w-50 text-uppercase rounded-pill">{t("boatOverview.buttonShowAll")}</Button>
								</Container>
							</div>
						</div>
					</div>

					<div>
						<div className="blockedView bg-white border my-2">
							<h2 className="my-3">{t("boatOverview.blockedBoats")}</h2>
							<div className="py-1">
								<Container>
									<div className="blocked-tiles text-center">
										<Row xs={1} md={2}>
											{boats.filter(x => !x.overdue).map(x =>
												<BoatTile isInUse={false} key={x.id} boatName={x.boatName} time={x.time} persons={x.seats + " Person"} blocked={true} clickEvent={() => { setInfoElement(x) }}></BoatTile>
											)}
										</Row>
									</div>
									<Button variant="light" onClick={() => navigate('/staff/manage')} className="mt-3 shadow-sm bg-white border w-50 text-uppercase rounded-pill">{t("boatOverview.buttonShowAll")}</Button>
								</Container>
							</div>
						</div>
					</div>

					<div>
						<div className="availableView bg-white border my-2">
							<h2 className="my-3">{t("boatOverview.availableBoats")}</h2>
							<div className="py-1">
								<Container>
									<div className="available-tiles text-center">
										<Row xs={1} md={2}>
											{boats.filter(x => !x.overdue).map(x =>
												<BoatTile isInUse={false} key={x.id} boatName={x.boatName} time={x.time} persons={x.seats + " Person"} blocked={false} clickEvent={() => { setInfoElement(x) }}></BoatTile>
											)}
										</Row>
									</div>
									<Button variant="light" onClick={() => navigate('/staff/manage')} className="mt-3 shadow-sm bg-white border w-50 text-uppercase rounded-pill">{t("boatOverview.buttonShowAll")}</Button>
								</Container>
							</div>
						</div>
					</div>

				</Row>
			</div>

			<StaffModal header={t("boatOverview.BoatInfo")} show={infoElement?.boatName} successText={t("boatOverview.EndRide")} successColor="dark" onHide={() => { setInfoElement(undefined) }} onSuccess={() => { setInfoElement(undefined) }}>
				<BoatInfo></BoatInfo>
			</StaffModal>

		</div>
	);
}

export default BoatOverview;
