import { Client } from "pg";
import { Dialect, Sequelize } from "sequelize";
import envVars from "../config";
import { initBoat } from "./models/Boat";
import { initBoatType } from "./models/BoatType";
import { initCheckIn } from "./models/CheckIn";
import { initEmployee } from "./models/Employee";
import { initSport } from "./models/Sport";

export default async function initializeDatabase() {
  await createDbIfNotExists();
  const sequelize = new Sequelize(
    envVars.DB_NAME,
    envVars.DB_USER,
    envVars.DB_PASSWORD,
    {
      host: envVars.DB_HOST,
      dialect: envVars.DB_DRIVER as Dialect,
      logging: false,
    }
  );
  await initEmployee(sequelize);
  const Sport = await initSport(sequelize);
  const Boat = await initBoat(sequelize);
  const BoatType = await initBoatType(sequelize);
  await initCheckIn(sequelize);

  BoatType.belongsToMany(Sport, { through: "Sport_BoatType" });
  Boat.hasOne(BoatType);

  await sequelize.sync({ alter: true });
}

async function createDbIfNotExists() {
  const client = new Client({
    host: envVars.DB_HOST,
    user: envVars.DB_USER,
    password: envVars.DB_PASSWORD,
  });
  // https://stackoverflow.com/questions/18389124/simulate-create-database-if-not-exists-for-postgresql
  await client.connect();
  const isDatabaseExistingQuery = await client.query(
    `SELECT * FROM pg_database WHERE datname='${envVars.DB_NAME}'`
  );
  const isDatabaseExisting = isDatabaseExistingQuery.rowCount === 1;
  if (!isDatabaseExisting) {
    await client.query(`CREATE DATABASE "${envVars.DB_NAME}"`);
  }
  client.end();
}
